@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::Test::CPAN::Changes;
 use strict;
 use warnings;
 # ABSTRACT: release tests for your changelog
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -34,6 +34,7 @@ no Moose;
 
 
 
+
 =pod
 
 =encoding utf-8
@@ -44,7 +45,7 @@ Dist::Zilla::Plugin::Test::CPAN::Changes - release tests for your changelog
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -76,8 +77,13 @@ and that file will be tested instead.
 
 =for Pod::Coverage munge_file
 
+=for test_synopsis 1;
+__END__
+
 =head1 AVAILABILITY
 
+The project homepage is L<http://p3rl.org/Dist::Zilla::Plugin::Test::CPAN::Changes>.
+
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-Test-CPAN-Changes/>.
@@ -97,7 +103,7 @@ and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Test-CPAN-Ch
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/doherty/Dist-Zilla-Plugin-Test-CPAN-Changes/issues>.
+L<https://github.com/doherty/Dist-Zilla-Plugin-Test-CPAN-Changes/issues>.
 
 =head1 AUTHOR
 
